
** Replication materials
** Journal: JEPP
** Article Title: "Policy-specific effects of transgovernmental cooperation: 
** a statistical assessment across the EUs post-Soviet neighbours" 
** Author: Dr. Karina Shyrokykh (LMU Munich)

** Data file: replication_material_Shyrokykh_data

xtset ccode year
drop if year >2014
drop if year <1992 

//for robustness check, limit the data to 2000-2010
*xtset ccode year
*drop if year >2010
*drop if year <2000 


* Table 1
sum zphysint zgoveffectiv hrtraining events logodaeu loggdppercapita ///
logpopulation intrawar interwar polity intencitysanctions regimechange ///
treaties logeudistance actions 

*Test for serial correlation
xtserial goveffectiv Levents Llogodaeu Lgoveffectiv LLgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance  Lactions year

* F-test for time-fixed effects 
xtreg physint LLhrtraining LLlogodaeu Lphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLcapacitywb LLlogeudistance LLactions i.year, fe cluster (ccode)
testparm i.year 

xtreg zgoveffectiv Levents Llogodaeu Lgoveffectiv LLLgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions i.year, fe cluster(ccode)
testparm i.year

* Pesaran CD test for cross-sectional dependence
xtcsd, pesaran abs 

* test for unit root
xtunitroot llc physint 
xtunitroot llc physint, lags (aic 10) demean 
xtunitroot breitung physint, robust 
xtunitroot llc hrtraining
xtunitroot llc hrtraining
xtunitroot llc events
xtunitroot llc newevents 
xtunitroot llc newevents, lags (aic 10) demean 
xtunitroot llc goveffectiv
xtunitroot breitung d.goveffectiv 
xtunitroot llc d.newevents 
xtunitroot ht d.newevents 
xtunitroot ht d.newevents, demean 
xtunitroot breitung d.newevents, robust 
xtunitroot llc d.Dgoveffectiv
xtunitroot llc DDgoveffectiv
xtunitroot llc DDDgoveffectiv 
xtunitroot llc physint, lag(1) 
xtunitroot llc goveffectiv, lag(1) 
xtunitroot llc Dgoveffectiv, lag(1) 
xtunitroot hadri physint 
xtunitroot hadri goveffectiv 
xtunitroot hadri Dgoveffectiv 
xtunitroot ht d.goveffectiv

xtunitroot fisher hrtraining, dfuller lags(1)
xtunitroot fisher hrtraining, dfuller lags(2)
xtunitroot fisher hrtraining, dfuller lags(3)
xtunitroot fisher hrtraining, dfuller lags(4)
xtunitroot fisher hrtraining, dfuller lags(5)



***********************************************************************************
*************************Model  1**************************************************
***********************************************************************************
xtreg zphysint DLLhrtraining LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions , fe cluster (ccode)
est sto e1, title (Model 1)

//non-standartized
xtreg physint DLLhrtraining LLlogodaeu Lphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions , fe cluster (ccode)
est sto e1b, title (Model 1b)

xtreg zphysint DLLhrtraining LLlogodaeu Lzphysint LLLzphysint d.LLloggdppercapita ///
d.LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions , fe cluster (ccode)

//time-trend
xtreg zphysint DLLhrtraining LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions year, fe cluster (ccode)

xtreg zphysint DLLhrtraining logodaeu Lzphysint LLLzphysint loggdppercapita ///
logpopulation intrawar interwar polity intensity regimechange  ///
treaties logeudistance actions year, fe cluster (ccode)

///////////////    Arellano-Bond 1991 model -- differenced GMM      ///////////

xtabond d.zphysint DLLhrtraining LLlogodaeu LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLcapacity LLactions year, nocons vce(robust)

xtabond d.zphysint DLLhrtraining LLlogodaeu LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLcapacity LLactions year, nocons ///
twostep vce(robust)
est sto e14, title (Model 14)

// Durbin-Wu-Housman test for endogeniety (endogeniety of DLLhrtraining)
reg hrtraining Lphysint

*drop hrtrain_res
predict hrtrain_res, res

reg zphysint DLLhrtraining LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions hrtrain_res

test hrtrain_res // no endogeniety (2SLS is not needed)
// But just to be sure, I run 2SLS 

//2sls
ivregress 2sls zphysint Llogodaeu Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions  (d.Lhrtraining =  L.zphysint LL.zphysint), vce(robust)

ivregress 2sls zphysint LLlogodaeu LLloggdppercapita ///
LLlogpopulation LLintrawar Linterwar LLpolity Lextent LLregimechange  ///
LLtreaties  LLactions  LLlogeudistance ///
(d.LLhrtraining =  LL.zphysint LLL.zphysint LLLL.zphysint ), vce(robust)

/////////////////////////////////    LATENT   //////////////////////////////

xtreg zlatentmean LLhrtraining LLlogodaeu Lzlatentmean LLLzlatentmean LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLtreaties ///
year LLcapacitywb LLlogeudistance , fe cluster (ccode)  
est sto e1a, title (Model 5)

//LATENT control
xtreg zphysint D.LLhrtraining LLlogodaeu latentmean Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLtreaties ///
year LLcapacitywb LLlogeudistance , fe cluster (ccode) 
est sto e1b, title (Model 6)

//Ordered probit FE
xtoprobit zphysint DLLhrtraining LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions LLcapacitywb i.ccode, nolog
est sto e1c, title (Model 7)

//Ordered probit RE
xtoprobit zphysint DLLhrtraining LLlogodaeu Lzphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions LLcapacitywb, nolog

xtreg d.zphysint d.DLLhrtraining LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLtreaties ///
year LLcapacitywb LLlogeudistance , fe cluster (ccode) 
est sto e1d, title (Model 8)

//2sls latentmean
ivregress 2sls zlatentmean Llogodaeu Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions  (d.Lhrtraining =  LL.zlatentmean LLL.zlatentmean), vce(robust)

ivregress 2sls zlatentmean LLlogodaeu LLloggdppercapita ///
LLlogpopulation LLintrawar Linterwar LLpolity Lextent LLregimechange  ///
LLtreaties  LLactions  LLlogeudistance ///
(d.LLhrtraining =  LL.zlatentmean LLL.zlatentmean LLLL.zlatentmean ), vce(robust)



***********************************************************************************
*************************Model  2**************************************************
***********************************************************************************

// Standartized first difference
xtreg zgoveffectiv Levents Llogodaeu Lzgoveffectiv LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions, fe cluster(ccode)
est sto e2, title (Model 2)
est sto lag1pa

//non-stand
xtreg goveffectiv Levents Llogodaeu Lgoveffectiv LLLgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions, fe cluster(ccode)
est sto e2b, title (Model 2b)


//Model 2: test for endogeniety with Durbin-Wu-Hausman test

reg events Lzgoveffectiv
predict events_res, res

xtreg zgoveffectiv Levents Llogodaeu Lzgoveffectiv LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions  events_res

test events_res //no endogeniety (models with IVs just for trial)
 
////////////////////////     GMM  & 2SLS    /////////////////////

xtabond d.zgoveffectiv d.Levents logodaeu LLrequesttaiex loggdppercapita ///
logpopulation intrawar interwar polity intencitysanctions regimechange ///
logeudistance actions , nocons twostep vce(robust)

xtabond d.zgoveffectiv d.Llogevents logodaeu LLrequesttaiex loggdppercapita ///
logpopulation intrawar interwar polity intencitysanctions regimechange ///
logeudistance actions , nocons twostep vce(robust)


ivregress 2sls d.zgoveffectiv  Llogodaeu  Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions year ///
(d.Levents = d.L.zgoveffectiv d.LL.zgoveffectiv), vce(robust)


// PCSE 
xtpcse  d.zgoveffectiv d.Levents Llogodaeu  Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions  LLLgoveffectiv i.ccode year, correlation ()

//without year-trend
xtpcse  d.zgoveffectiv d.Levents Llogodaeu  Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions  LLLgoveffectiv i.ccode , correlation ()


///////////////////////  Robustness check ///////////////////////////////////
xtreg d.zgoveffectiv Levents Llogodaeu Lzgoveffectiv LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions, fe cluster(ccode)
est sto e2a, title (Model 9)


xtreg zgoveffectiv Levents Llogodaeu Lzgoveffectiv LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions year, re vce(robust)
est sto e2b, title (Model 10)

xtreg zgoveffectiv Levents Llogodaeu Lzgoveffectiv LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions i.year, vce(robust)

//altrenative lag -- 2 years 
xtreg d.zgoveffectiv LLevents LLlogodaeu Lzgoveffectiv LLLzgoveffectiv LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange ///
LLlogeudistance LLactions, fe cluster(ccode)
est sto e2c, title (Model 11)
est sto lag2pa

//alternative lag
xtreg d.zgoveffectiv LLLevents LLLlogodaeu Lgoveffectiv LLLLLgoveffectiv LLLloggdppercapita ///
LLLlogpopulation LLLintrawar LLLinterwar LLLpolity LLLextent LLLregimechange ///
LLLlogeudistance LLLactions year, fe cluster(ccode)
est sto lag3pa

xtreg d.goveffectiv LLLLevents LLLLlogodaeu Lgoveffectiv /// 
LLLLLLgoveffectiv LLLLloggdppercapita ///
LLLLlogpopulation LLLLintrawar LLLLinterwar LLLLpolity LLLLextent LLLLregimechange ///
LLLLlogeudistance LLLLactions , fe cluster(ccode)

xtreg d.zgoveffectiv LLLLevents LLLLlogodaeu Lzgoveffectiv /// 
LLLLLLzgoveffectiv LLLLloggdppercapita ///
LLLLlogpopulation LLLLintrawar LLLLinterwar LLLLpolity LLLLextent LLLLregimechange ///
LLLLlogeudistance LLLLactions year, fe cluster(ccode)
est sto e2d, title (Model 13)
est sto lag4pa

// Figure 1b (appendix)
coefplot lag1pa lag2pa lag3pa lag4pa ///
, keep( Levents || LLevents || LLLevents || LLLLevents) xline(0)

***********************************************************************************
*************************Model  3**************************************************
***********************************************************************************

// Hypothesis 3 
xtreg zphysint c.LLhrtraining##i.LLactions LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent, fe vce(robust)
est sto e3, title (Model 3)

xtreg d.zphysint c.DLLhrtraining##i.LLactions LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent, fe vce(robust)

xtreg zphysint c.LLhrtraining##i.LLactions LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent year, fe vce(robust)

***
xtreg zphysint c.LLhrtraining##i.LLactions LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent, re vce(robust)

***********************************************************************************
*************************Model  4**************************************************
***********************************************************************************

xtreg zgoveffectiv c.Levents##i.Lactions Llogodaeu Lzgoveffectiv ///
LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance, fe vce(robust)
est sto e4, title (Model 4)

xtreg zgoveffectiv c.Levents##i.Lactions Llogodaeu Lzgoveffectiv ///
LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance year, fe vce(robust)

//differentiated
xtreg d.zphysint c.DLLhrtraining##i.LLactions LLlogodaeu Lphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent LLcapacitywb, fe vce(robust)

xtreg d.zgoveffectiv c.Levents##i.actions Llogodaeu Lgoveffectiv ///
LLLgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance, fe vce(robust)

**
xtreg zgoveffectiv c.Levents##i.Lactions Llogodaeu Lzgoveffectiv ///
LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance, re vce(robust)

// Alternative laggs

set more off
xtreg d.zphysint DLhrtraining Llogodaeu Lzphysint LLzphysint Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions, fe cluster (ccode)
est sto lag1

xtreg d.zphysint DLLhrtraining LLlogodaeu Lphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions , fe cluster (ccode)
est sto lag2

xtoprobit zphysint DLLhrtraining LLlogodaeu Lphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions LLcapacitywb i.ccode, nolog
est sto lag2op

xtreg d.zphysint DLLLhrtraining LLLlogodaeu Lphysint LLLLphysint LLLloggdppercapita ///
LLLlogpopulation LLLintrawar LLLinterwar LLLpolity LLLextent LLLregimechange  ///
LLLtreaties LLLlogeudistance LLLactions , fe cluster (ccode)
est sto lag3

xtreg d.zphysint DLLLLhrtraining LLLLlogodaeu Lphysint LLLLLphysint LLLLloggdppercapita ///
LLLLlogpopulation LLLLintrawar LLLLinterwar LLLLpolity LLLLextent LLLLregimechange  ///
LLLLtreaties LLLLlogeudistance LLLLactions, fe cluster (ccode)
est sto lag4


xtreg d.zphysint d.LLLLhrtraining LLLLlogodaeu Lphysint LLLLLphysint LLLLloggdppercapita ///
LLLLlogpopulation LLLLintrawar LLLLinterwar LLLLpolity LLLLextent LLLLregimechange  ///
LLLLtreaties LLLLlogeudistance LLLLactions , fe cluster (ccode)
est sto lag5

//Fig 1a in appendix
coefplot lag1 lag2 lag3 lag4 ///
, keep( DLhrtraining || DLLhrtraining || DLLLhrtraining || DLLLhrtraining ///
|| DLLLLhrtraining) xline(0)



//Time-fixed effects
xtreg zphysint DLhrtraining Llogodaeu Lphysint LLLphysint Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions year, fe cluster (ccode)

xtreg zphysint DLLhrtraining Llogodaeu Lphysint LLLphysint Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions i.year, fe cluster (ccode)

xtreg d.zphysint DLLhrtraining Llogodaeu Lphysint LLLphysint Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange  ///
Ltreaties Llogeudistance Lactions i.year, fe cluster (ccode)


/////////////// COMPARING EFFECTS AND MARGINS PLOTS ////////////////////////////

// Graph 1 (models 1 and 2) Post-estimation margin-plot 
set more off
xtreg zphysint LLhrtraining LLlogodaeu Lphysint LLLphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange  ///
LLtreaties LLlogeudistance LLactions , fe 
margins, at (LLhrtraining=(0(10)100))
marginsplot, recast (line) recastci(rarea) name(margins1a, replace)


set more off
xtreg d.zgoveffectiv Levents Llogodaeu Lgoveffectiv LLLgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance Lactions, fe 
margins, at (Levents=(0(10)100))
marginsplot, recast (line) recastci(rarea) name(margins1b, replace)


//Model 4 and 4 post-estimation 
set more off
xtreg zphysint c.LLhrtraining##i.LLactions LLlogodaeu Lzphysint LLLzphysint LLloggdppercapita ///
LLlogpopulation LLintrawar LLinterwar LLpolity LLextent LLregimechange LLlogeudistance ///
LLtreaties LLextent, fe vce(robust)
margins LLactions, at(LLhrtraining=(0(10)100))
marginsplot, recast (line) recastci(rarea) name(margins3a, replace)


set more off
xtreg zgoveffectiv c.Levents#i.actions Lactions Levents Llogodaeu Lzgoveffectiv ///
LLLzgoveffectiv Lloggdppercapita ///
Llogpopulation Lintrawar Linterwar Lpolity Lextent Lregimechange ///
Llogeudistance, fe vce(robust)
margins actions , at(Levents=(0(10)100))
marginsplot, xdimension(at(Levents))
marginsplot, recast (line) recastci(rarea) name(margins3b, replace)


//Table 2
esttab e1 e1b e2 e2b e3 e4 using ///
"C:/Users/Lokaladmin/Desktop/Table2.rtf", ///
cells(b(star fmt(3)) se(par fmt(2))) ///
legend label title(Table 2) ///
nonumbers mtitles("Model 1." "Model 1b." ///
"Model 2." "Model 2b." "Model 3." "Model 4." ) ///
star(* 0.10 ** 0.05 *** 0.01) r2 replace

//Appendix Table -- supplementary material
esttab e1a e1b e1c e1d e2a e2b e2c e2d using ///
"C:/Users/Lokaladmin/Desktop/AppendixTable1.rtf", ///
cells(b(star fmt(3)) se(par fmt(2))) ///
legend label title(Appendix Table. (cf. Table 2 in the manuscript).) ///
nonumbers mtitles("Model 5." "Model 6." "Model 7." "Model 8." "Model 9." ///
"Model 10." "Model 11."  "Model 12." "Model 13." ) ///
star(* 0.10 ** 0.05 *** 0.01) r2(3) ar2(3) scalars(F bic aic) nogaps replace

//Non-standardized coefficients for models 1b and 2b
esttab e1b e2b using ///
"C:/Users/Lokaladmin/Desktop/Table2.rtf", ///
cells(b(star fmt(3)) se(par fmt(2))) ///
legend label title(Table 1b) ///
nonumbers mtitles("Model 1b" "Model 2b" ) ///
star(* 0.10 ** 0.05 *** 0.01) r2 replace



//Graphs for the appendix 

//For graph 1992-2011 (Fugure 1a)
*xtset ccode year
*drop if year >2011
*drop if year <1992 

scatter hrtraining year, jitter(7)

//For graph 1996-2014 (Fugure 1b)
*drop if year >2014
*drop if year <1996 

scatter events year, jitter(7)


**************************Matching method***************************************
**********************Difference-in-difference********************************** 
********************************************************************************

//1. Use treatemnt with a time lag where:

*Levents = l.events
*LLevents = ll.events
*LLLevents = lll.events

//comment-out the code above if need to re-run generation of the vars.
// NB: the lags are chosen in accordence to the results obtained with regression analysis


//2. Dummy for treatemnt group (1= treatment group, 0 = control group)

// Only seven countries are treated (Armenia, Azerbaijan, Belarus, Georgia,  
//Moldova, Russia, and Ukraine), the Central Asian Republics are not eligible.
gen Dtr = 0
replace Dtr = 1 if ccode == 369 |  ccode == 359 | /// 
ccode == 370 |  ccode == 371 |  ccode == 373 | ccode == 365 |  ccode == 372
list ccode year Dtr

//3. Interact intensity of treatemnt and treatemnt group dummy
gen LeventsXDtr = Levents*Dtr
gen LLeventsXDtr = LLevents*Dtr
gen LLLeventsXDtr = LLLevents*Dtr

// for t-1
xtreg goveffectiv LeventsXDtr Levents Dtr Lgoveffectiv ///
Lloggdppercapita Llogpopulation Lintrawar Linterwar Lpolity Lextent ///
Llogodaeu Lactions Lregimechange i.ccode, robust
est sto e12, title (Model 12)

// for t-2
xtreg goveffectiv LLeventsXDtr LLevents Dtr Lgoveffectiv ///
LLloggdppercapita LLlogpopulation LLintrawar LLinterwar LLpolity LLextent ///
LLlogodaeu LLactions LLregimechange i.ccode, robust
est sto e13, title (Model 13)

// for t-3
xtreg goveffectiv LLLeventsXDtr LLLevents Dtr Lgoveffectiv ///
LLLloggdppercapita LLLlogpopulation LLLintrawar LLLinterwar LLLpolity LLLextent ///
LLLlogodaeu LLLactions LLLregimechange i.ccode, robust
est sto e14, title (Model 14)

//Table 1b
esttab e12 e13 e14 using ///
"C:/Users/Admin/Desktop/Table1b.rtf", ///
cells(b(star fmt(3)) se(par fmt(2))) ///
legend label title(Table 1b) ///
nonumbers mtitles("Model 12" "Model 13" "Model 14" ) ///
star(* 0.10 ** 0.05 *** 0.01) r2 replace


